==> nextcloud-29.0.5.tgz: nextcloud/apps/twofactor_backupcodes/l10n/is.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Þú útbjóst tveggja-þrepa öryggisafritunarkóða fyrir aðganginn þinn",
    "Second-factor backup codes" : "Tveggja-þrepa öryggisafritunarkóðar",
    "Generate backup codes" : "Útbúa öryggisafritunarkóða",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Þú virkjaðir tveggja-þrepa auðkenningu en hefur ekki ennþá útbúið öryggisafritunarkóða. Þeir eru nauðsynlegir til að geta endurheimt aðganginn þinn fari svo að þú tapir seinni þætti auðkenningarinnar.",
    "Backup code" : "Öryggisafritunarkóði",
    "Use backup code" : "Nota öryggisafritunarkóða",
    "Two factor backup codes" : "Tveggja-þrepa öryggisafritunarkóðar",
    "A two-factor auth backup codes provider" : "Útgefandi tveggja-þrepa öryggisafritunarkóða",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Öryggisafritunarkóðar hafa verið útbúnir. {used} af {total} kóðum hafa verið notaðir.",
    "Save backup codes" : "Vista öryggisafritunarkóða",
    "Print backup codes" : "Prenta öryggisafritunarkóða",
    "Regenerate backup codes" : "Endurnýja öryggisafritunarkóða",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Ef þú endurnýjar öryggisafritunarkóða, gerir þú sjálfkrafa eldri kóða ógilda.",
    "An error occurred while generating your backup codes" : "Villa kom upp við að búa til öryggisafritunarkóðana þína",
    "{name} backup codes" : "{name} öryggisafritunarkóðar",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Notaðu einn af öryggisafritunarkóðunum sem þú vistaðir þegar þú settir upp tveggja-þátta auðkenningu.",
    "Submit" : "Senda inn",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Þetta eru öryggisafritunarkóðarnir þínir. Vistaðu þá og/eða prentaðu þá út, því þú munt ekki geta lesið þá aftur síðar í ferlinu"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/twofactor_backupcodes/l10n/is.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Þú útbjóst tveggja-þrepa öryggisafritunarkóða fyrir aðganginn þinn",
    "Second-factor backup codes" : "Tveggja-þrepa öryggisafritunarkóðar",
    "Generate backup codes" : "Útbúa öryggisafritunarkóða",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Þú virkjaðir tveggja-þrepa auðkenningu en hefur ekki ennþá útbúið öryggisafritunarkóða. Þeir eru nauðsynlegir til að geta endurheimt aðganginn þinn fari svo að þú tapir seinni þætti auðkenningarinnar.",
    "Backup code" : "Öryggisafritunarkóði",
    "Use backup code" : "Nota öryggisafritunarkóða",
    "Two factor backup codes" : "Tveggja-þrepa öryggisafritunarkóðar",
    "A two-factor auth backup codes provider" : "Útgefandi tveggja-þrepa öryggisafritunarkóða",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Öryggisafritunarkóðar hafa verið útbúnir. {used} af {total} kóðum hafa verið notaðir.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "Þetta eru öryggisafritunarkóðarnir þínir. Vistaðu þá og/eða prentaðu þá út, því þú munt ekki geta lesið þá aftur síðar í ferlinu.",
    "Save backup codes" : "Vista öryggisafritunarkóða",
    "Print backup codes" : "Prenta öryggisafritunarkóða",
    "Regenerate backup codes" : "Endurnýja öryggisafritunarkóða",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Ef þú endurnýjar öryggisafritunarkóða, gerir þú sjálfkrafa eldri kóða ógilda.",
    "An error occurred while generating your backup codes" : "Villa kom upp við að búa til öryggisafritunarkóðana þína",
    "{name} backup codes" : "{name} öryggisafritunarkóðar",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Notaðu einn af öryggisafritunarkóðunum sem þú vistaðir þegar þú settir upp tveggja-þátta auðkenningu.",
    "Submit" : "Senda inn",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Þetta eru öryggisafritunarkóðarnir þínir. Vistaðu þá og/eða prentaðu þá út, því þú munt ekki geta lesið þá aftur síðar í ferlinu"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
